[llvm-commits] [llvm] r92662 - /llvm/trunk/lib/VMCore/ValueSymbolTable.cpp

David Greene greened at obbligato.org
Mon Jan 4 17:30:06 PST 2010


Author: greened
Date: Mon Jan  4 19:30:06 2010
New Revision: 92662

URL: http://llvm.org/viewvc/llvm-project?rev=92662&view=rev
Log:
Change errs() to dbgs().

Modified:
    llvm/trunk/lib/VMCore/ValueSymbolTable.cpp

Modified: llvm/trunk/lib/VMCore/ValueSymbolTable.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/VMCore/ValueSymbolTable.cpp?rev=92662&r1=92661&r2=92662&view=diff

==============================================================================
--- llvm/trunk/lib/VMCore/ValueSymbolTable.cpp (original)
+++ llvm/trunk/lib/VMCore/ValueSymbolTable.cpp Mon Jan  4 19:30:06 2010
@@ -24,7 +24,7 @@
 ValueSymbolTable::~ValueSymbolTable() {
 #ifndef NDEBUG   // Only do this in -g mode...
   for (iterator VI = vmap.begin(), VE = vmap.end(); VI != VE; ++VI)
-    errs() << "Value still in symbol table! Type = '"
+    dbgs() << "Value still in symbol table! Type = '"
            << VI->getValue()->getType()->getDescription() << "' Name = '"
            << VI->getKeyData() << "'\n";
   assert(vmap.empty() && "Values remain in symbol table!");
@@ -38,7 +38,7 @@
 
   // Try inserting the name, assuming it won't conflict.
   if (vmap.insert(V->Name)) {
-    //DEBUG(errs() << " Inserted value: " << V->Name << ": " << *V << "\n");
+    //DEBUG(dbgs() << " Inserted value: " << V->Name << ": " << *V << "\n");
     return;
   }
   
@@ -62,14 +62,14 @@
       // Newly inserted name.  Success!
       NewName.setValue(V);
       V->Name = &NewName;
-     //DEBUG(errs() << " Inserted value: " << UniqueName << ": " << *V << "\n");
+     //DEBUG(dbgs() << " Inserted value: " << UniqueName << ": " << *V << "\n");
       return;
     }
   }
 }
 
 void ValueSymbolTable::removeValueName(ValueName *V) {
-  //DEBUG(errs() << " Removing Value: " << V->getKeyData() << "\n");
+  //DEBUG(dbgs() << " Removing Value: " << V->getKeyData() << "\n");
   // Remove the value from the symbol table.
   vmap.remove(V);
 }
@@ -82,7 +82,7 @@
   ValueName &Entry = vmap.GetOrCreateValue(Name);
   if (Entry.getValue() == 0) {
     Entry.setValue(V);
     //DEBUG(errs() << " Inserted value: " << Entry.getKeyData() << ": "
     //           << *V << "\n");
     return &Entry;
   }
@@ -102,7 +102,7 @@
     if (NewName.getValue() == 0) {
       // Newly inserted name.  Success!
       NewName.setValue(V);
-     //DEBUG(errs() << " Inserted value: " << UniqueName << ": " << *V << "\n");
+     //DEBUG(dbgs() << " Inserted value: " << UniqueName << ": " << *V << "\n");
       return &NewName;
     }
   }
@@ -112,10 +112,10 @@
 // dump - print out the symbol table
 //
 void ValueSymbolTable::dump() const {
-  //DEBUG(errs() << "ValueSymbolTable:\n");
+  //DEBUG(dbgs() << "ValueSymbolTable:\n");
   for (const_iterator I = begin(), E = end(); I != E; ++I) {
-    //DEBUG(errs() << "  '" << I->getKeyData() << "' = ");
+    //DEBUG(dbgs() << "  '" << I->getKeyData() << "' = ");
     I->getValue()->dump();
-    //DEBUG(errs() << "\n");
+    //DEBUG(dbgs() << "\n");
   }
 }
@@ -82,7 +82,7 @@
   if (Entry.getValue() == 0) {
     Entry.setValue(V);
-    //DEBUG(errs() << " Inserted value: " << Entry.getKeyData() << ": "
+    //DEBUG(dbgs() << " Inserted value: " << Entry.getKeyData() << ": "
     //           << *V << "\n");
     return &Entry;





More information about the llvm-commits mailing list